@@ -25,7 +25,7 @@
  *
  */
 
-static const char revision[] = "$Id: qslogger.c,v 1.9 2012/06/01 16:03:04 pbuchbinder Exp $";
+static const char revision[] = "$Id: qslogger.c,v 1.11 2012/11/23 20:21:51 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -246,7 +246,7 @@ static void usage(const char *cmd, int man) {
   qs_man_print(man, "     determine the severity (syslog level) for each log line.\n");
   qs_man_print(man, "     The default pattern '"QS_DEFAULTPATTERN"' can\n");
   qs_man_print(man, "     be used for Apache error log messages but you may configure\n");
-  qs_man_print(man, "     your own pattern matchin and other log format too. Use brackets\n");
+  qs_man_print(man, "     your own pattern matching and other log format too. Use brackets\n");
   qs_man_print(man, "     to define the string enclosing the severity string.\n");
   qs_man_print(man, "     Default level (if severity can't be determined) is defined by the\n");
   qs_man_print(man, "     option '-d' (see below).\n");
@@ -284,7 +284,7 @@ static void usage(const char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qslog(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://opensource.adnovum.ch/mod_qos/\n");
   } else {
